# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

Puppet::Type.type(:bsu_patch).provide(:bsu_patch) do
  def self.instances
    []
  end

  def bsu_patch(action)
    user = resource[:os_user]
    patch_name = resource[:name]
    middleware_home_dir = resource[:middleware_home_dir]
    weblogic_home_dir   = resource[:weblogic_home_dir]
    patch_download_dir  = resource[:patch_download_dir]

    bsuaction = if action == :present
                  '-install'
                else
                  '-remove'
                end

    Puppet.debug "bsu_patch action: #{action}"

    if patch_download_dir.nil?
      command = "cd #{middleware_home_dir}/utils/bsu;#{middleware_home_dir}/utils/bsu/bsu.sh #{bsuaction} -patchlist=#{patch_name} -prod_dir=#{weblogic_home_dir} -verbose"
    else
      # rubocop:disable Layout/LineLength
      command = "cd #{middleware_home_dir}/utils/bsu;#{middleware_home_dir}/utils/bsu/bsu.sh #{bsuaction} -patchlist=#{patch_name} -prod_dir=#{weblogic_home_dir} -patch_download_dir=#{patch_download_dir} -verbose"
      # rubocop:enable Layout/LineLength
    end

    kernel = Facter.value(:kernel)
    su_shell = kernel == 'Linux' ? '-s /bin/bash' : ''

    Puppet.debug "bsu_patch action: #{action} with command #{command}"
    output = `su #{su_shell} - #{user} -c 'export USER="#{user}";export LOGNAME="#{user}";#{command}'`
    Puppet.debug "bsu_patch result: #{output}"

    # Check for 'Result: Success' else raise

    result = false
    output.each_line do |li|
      unless li.nil?
        # rubocop:disable all
        if li.include? 'Result: Success'
          result = true
        end
        # rubocop:enable all
      end
    end
    fail(output) if result == false

    Puppet.info 'bsu_patch done'
  end

  def bsu_status
    user = resource[:os_user]
    patch_name = resource[:name]
    middleware_home_dir = resource[:middleware_home_dir]
    weblogic_home_dir   = resource[:weblogic_home_dir]
    patch_download_dir  = resource[:patch_download_dir]

    command = if patch_download_dir.nil?
                "cd #{middleware_home_dir}/utils/bsu;#{middleware_home_dir}/utils/bsu/bsu.sh -view -status=applied -prod_dir=#{weblogic_home_dir} -verbose"
              else
                "cd #{middleware_home_dir}/utils/bsu;#{middleware_home_dir}/utils/bsu/bsu.sh -view -status=applied -prod_dir=#{weblogic_home_dir} -patch_download_dir=#{patch_download_dir} -verbose"
              end

    kernel = Facter.value(:kernel)
    su_shell = kernel == 'Linux' ? '-s /bin/bash' : ''

    Puppet.debug "bsu_status for patch #{patch_name} command: #{command}"
    output = `su #{su_shell} - #{user} -c '#{command}'`

    output.each_line do |li|
      next if li.nil?

      Puppet.debug "line #{li}"
      if li.include? patch_name
        Puppet.debug 'found patch'
        return patch_name
      end
    end
    'NotFound'
  end

  def present
    bsu_patch :present
  end

  def absent
    bsu_patch :absent
  end

  def status
    output = bsu_status
    patch_id = resource[:name]
    Puppet.debug "bsu_status output #{output} for patchId #{patch_id}"
    if output == patch_id
      :present
    else
      :absent
    end
  end
end
