# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

Puppet::Type.type(:opatch).provide(:opatch) do
  def self.instances
    []
  end

  def opatch(action)
    user = resource[:os_user]
    patch_name = resource[:name]
    oracle_product_home_dir = resource[:oracle_product_home_dir]
    jdk_home_dir            = resource[:jdk_home_dir]
    extracted_patch_dir     = resource[:extracted_patch_dir]

    command = if action == :present
                "#{oracle_product_home_dir}/OPatch/opatch apply -silent -jre #{jdk_home_dir}/jre -oh #{oracle_product_home_dir} #{extracted_patch_dir}"
              else
                "#{oracle_product_home_dir}/OPatch/opatch rollback -id #{patch_name} -silent -jre #{jdk_home_dir}/jre -oh #{oracle_product_home_dir}"
              end

    Puppet.debug "opatch action: #{action} with command #{command}"
    kernel = Facter.value(:kernel)
    su_shell = kernel == 'Linux' ? '-s /bin/bash' : ''

    output = `su #{su_shell} - #{user} -c '#{command}'`
    Puppet.debug "opatch result: #{output}"

    result = false
    output.each_line do |li|
      unless li.nil?
        # rubocop:disable all
        if li.include? 'OPatch completed' or li.include? 'OPatch succeeded'
          result = true
        end
        # rubocop:enable all
      end
    end
    fail(output) if result == false
  end

  def opatch_status
    user = resource[:os_user]
    patch_name = resource[:name]
    oracle_product_home_dir = resource[:oracle_product_home_dir]
    orainst_dir             = resource[:orainst_dir]

    command = "#{oracle_product_home_dir}/OPatch/opatch lsinventory -patch_id -oh #{oracle_product_home_dir} -invPtrLoc #{orainst_dir}/oraInst.loc"
    Puppet.debug "opatch_status for patch #{patch_name} command: #{command}"

    kernel = Facter.value(:kernel)
    su_shell = kernel == 'Linux' ? '-s /bin/bash' : ''

    output = `su #{su_shell} - #{user} -c '#{command}'`

    output.each_line do |li|
      opatch = "#{li[5, li.index(':') - 5].strip};" if li['Patch'] && li[': applied on']
      next if opatch.nil?

      Puppet.debug "line #{opatch}"
      if opatch.include? patch_name
        Puppet.debug 'found patch'
        return patch_name
      end
    end
    'NotFound'
  end

  def present
    opatch :present
  end

  def absent
    opatch :absent
  end

  def status
    output = opatch_status
    patch_id = resource[:name]
    Puppet.debug "opatch_status output #{output} for patchId #{patch_id}"
    if output == patch_id
      :present
    else
      :absent
    end
  end
end
