# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet
  Type.newtype(:bsu_patch) do
    def self.module_name
      'wls_install'
    end
    desc 'This is the WebLogic Patch process called BSU'

    newproperty(:ensure) do
      desc 'Whether a patch should be applied.'

      newvalue(:present, :event => :bsu_installed) do
        provider.present
      end

      newvalue(:absent, :event => :bsu_absent) do
        provider.absent
      end

      aliasvalue(:installed, :present)
      aliasvalue(:purged, :absent)

      def retrieve
        provider.status
      end

      def sync
        event = super()
        # rubocop:disable all
        if property = @resource.property(:enable)
          val = property.retrieve
          property.sync unless property.safe_insync?(val)
        end
        # rubocop:enable all
        event
      end
    end

    newparam(:name) do
      desc <<-DESC
        The name of the BSU WebLogic Patch.
      DESC
      isnamevar
    end

    newparam(:os_user) do
      desc <<-DESC
        The weblogic operating system user.
      DESC
    end

    newparam(:middleware_home_dir) do
      desc <<-DESC
        The middleware home folder.
      DESC
    end

    newparam(:jdk_home_dir) do
      desc <<-DESC
        The JDK home folder.
      DESC
    end

    newparam(:weblogic_home_dir) do
      desc <<-DESC
        The weblogic home home folder.
      DESC
    end

    newparam(:patch_download_dir) do
      desc <<-DESC
        The BSU pathc download dir folder.
      DESC
    end
  end
end
