# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet
  Type.newtype(:opatch) do
    def self.module_name
      'wls_install'
    end
    desc 'This is the Oracle Patch process called OPatch'

    newproperty(:ensure) do
      desc 'Whether a patch should be applied.'

      newvalue(:present, :event => :opatch_installed) do
        provider.present
      end

      newvalue(:absent, :event => :opatch_absent) do
        provider.absent
      end

      aliasvalue(:installed, :present)
      aliasvalue(:purged, :absent)

      def retrieve
        provider.status
      end

      def sync
        event = super()
        # rubocop:disable all
        if property = @resource.property(:enable)
          val = property.retrieve
          property.sync unless property.safe_insync?(val)
        end
        # rubocop:enable all
        event
      end
    end

    newparam(:name) do
      desc <<-DESC
        The name of the OPatch.
      DESC
      isnamevar
    end

    newparam(:os_user) do
      desc <<-DESC
        The weblogic operating system user.
      DESC
    end

    newparam(:oracle_product_home_dir) do
      desc <<-DESC
        The oracle product home folder.
      DESC
    end

    newparam(:jdk_home_dir) do
      desc <<-DESC
        The JDK home folder.
      DESC
    end

    newparam(:orainst_dir) do
      desc <<-DESC
        The orainst folder.
      DESC
    end

    newparam(:extracted_patch_dir) do
      desc <<-DESC
        The extracted patch folder.
      DESC
    end
  end
end
